==========
pyoadr-ven
==========


.. image:: https://img.shields.io/pypi/v/pyoadr_ven.svg
        :target: https://pypi.python.org/pypi/pyoadr_ven

.. image:: https://img.shields.io/travis/carboncoop/pyoadr_ven.svg
        :target: https://travis-ci.org/carboncoop/pyoadr_ven

.. image:: https://readthedocs.org/projects/pyoadr-ven/badge/?version=latest
        :target: https://pyoadr-ven.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




OpenADR Virtual End Node


* Free software: Apache Software License 2.0
* Documentation: https://pyoadr-ven.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
